import argparse
from python_project_minify.python_project_minify import directory

from pkg_resources import get_distribution, DistributionNotFound

try:
    __version__ = get_distribution('python_project_minify').version
except DistributionNotFound:
    __version__ = '0.0.0'

def main():

    parser = argparse.ArgumentParser(prog='minifyProject', description='Minify Python Project Source')
    parser.add_argument('src', type=str, help='The project source directory')
    parser.add_argument('dst', type=str, help='The minified project destination directory')

    args = parser.parse_args()

    directory(args.src,args.dst)

if __name__ == '__main__':
    main()


import os
import python_minifier
from shutil import copyfile
from pathlib import Path
from .ignore import get_list

def directory(src, dst):
    
    ## Format paths
    src = os.path.abspath(src)+os.sep
    dst = os.path.abspath(dst)+os.sep

    ## Get a list of files to be ignored
    ignore = get_list('{}/.ppmignore'.format(src))

    ## Create a loop from src directory
    for root, dirs, files in os.walk(src, topdown=True):

        ## Don't need absolute path
        curdir = root.replace(os.path.normpath(src), '')

        curdir_list = curdir.split('\\')

        ## Ignore in root
        if os.path.normpath('/{}'.format(curdir_list[0])) in ignore:
            continue

        ## Static path ignore
        if os.path.normpath(curdir) in ignore:
            continue

        ## Wildcard ignores
        should_skip = False
        for sub in curdir_list:
            if os.path.normpath('*/{}').format(sub) in ignore:
                should_skip = True
                continue
        if should_skip:
            continue

        ## Generate directory
        newdir = os.path.abspath(dst) + curdir
        if not os.path.exists(newdir) and os.path.isdir(Path(newdir).parent.absolute()):
            os.mkdir(newdir)

        ## Create loop from files in folder
        filedir = os.path.abspath(src) + curdir
        for file in os.listdir(filedir):
            if not os.path.isdir(os.path.join(filedir, file)) and os.path.isdir(Path(newdir).parent.absolute()):
                filename = os.fsdecode(file)

                ## Ignore in root
                if filedir == os.path.abspath(src) + os.sep:
                    if filename in ignore:
                        continue

                ## Static path ignore
                if os.path.normpath(curdir)[1:] + os.sep + filename in ignore:
                    continue

                ## Wildcard ignores
                if '*{}'.format(filename) in ignore:
                    continue

                ## If Python file, minify
                if filename.endswith(".py"):
                    
                    with open(filedir + os.sep + filename) as f:
                        minified = python_minifier.minify(f.read())

                    with open(newdir + os.sep + filename, 'w') as f:
                        f.write(minified)
                    continue
                    
                ## If not Python file, just copy
                copyfile(filedir + os.sep + filename, newdir + os.sep + filename)

    return


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="python-project-minify",
    version="0.0.1",
    author="Wibo Kuipers",
    author_email="w.kuipers@filmage.nl",
    description="A quick way to compile your Python project into it's most compact form. Built on the great python-minify package.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/w-kuipers/python-project-minify",
    project_urls={
        "Bug Tracker": "https://github.com/w-kuipers/python-project-minify/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = {
        'console_scripts': ['minify-project=python_project_minify.__main__:main']
    },
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)


import os

def get_list(ignore_file):

    ## Need empty list
    ignore = []

    ## Check if file exists
    if not os.path.exists(ignore_file):
        return [] ## Return empty list if file not exist

    ## Read file and create list of lines
    with open(ignore_file, "r") as f:
        for l in f:
            if l == '\n' or l.lstrip()[0] == '#': ## Ignore empty lines and commented lines
                continue

            ignore.append(os.path.normpath(l.strip()))

    ## Add .ppmignore to list
    if not 'PRESERVE_PPMIGNORE' in ignore:
        ignore.append('*.ppmignore')

    return ignore